Sessions
========

.. module:: sqlalchemy.orm


.. autofunction:: create_session

.. autofunction:: scoped_session

.. autofunction:: sessionmaker

.. autoclass:: sqlalchemy.orm.session.Session
   :members:

.. autoclass:: sqlalchemy.orm.scoping.ScopedSession
   :members:
